@@ -1,4 +1,4 @@
-import numpy
+import numpy as np
 
 from ..helpers import multi_newton
 from .geometry import Geometry
@@ -6,12 +6,12 @@ from .geometry import Geometry
 
 class Ellipse(Geometry):
     def __init__(self, x0, a, b):
+        super().__init__()
         self.x0 = x0
         self.a = a
         self.b = b
         self.bounding_box = [x0[0] - a, x0[0] + a, x0[1] - b, x0[1] + b]
-        self.feature_points = numpy.array([])
-        return
+        self.feature_points = np.array([])
 
     def dist(self, x):
         assert x.shape[0] == 2
@@ -26,11 +26,11 @@ class Ellipse(Geometry):
         ay = (x[1] - self.x0[1]) / self.b
 
         alpha = ax ** 2 + ay ** 2 - 1.0
-        jac = numpy.array([4 * alpha * ax / self.a, 4 * alpha * ay / self.b])
+        jac = np.array([4 * alpha * ax / self.a, 4 * alpha * ay / self.b])
 
         dalpha_dx = 2 * ax / self.a
         dalpha_dy = 2 * ay / self.b
-        hess = numpy.array(
+        hess = np.array(
             [
                 [
                     4 * dalpha_dx * ax / self.a + 4 * alpha / self.a ** 2,
@@ -43,7 +43,7 @@ class Ellipse(Geometry):
             ]
         )
 
-        p = -numpy.linalg.solve(numpy.moveaxis(hess, -1, 0), jac.T)
+        p = -np.linalg.solve(np.moveaxis(hess, -1, 0), jac.T)
         return x + p.T
 
     def boundary_step(self, x):
