@@ -1,15 +1,15 @@
-import numpy
+import numpy as np
 
 from .geometry import Geometry
 
 
 class Scaling(Geometry):
     def __init__(self, geometry, alpha):
+        super().__init__()
         self.geometry = geometry
         self.alpha = alpha
-        self.bounding_box = alpha * numpy.array(geometry.bounding_box)
-        self.feature_points = numpy.array([])
-        return
+        self.bounding_box = alpha * np.array(geometry.bounding_box)
+        self.feature_points = np.array([])
 
     def dist(self, x):
         return self.geometry.dist(x / self.alpha)
