@@ -1,10 +1,11 @@
-import numpy
+import numpy as np
 
 from .geometry import Geometry
 
 
 class Translation(Geometry):
     def __init__(self, geometry, v):
+        super().__init__()
         self.geometry = geometry
         self.v = v
 
@@ -14,7 +15,7 @@ class Translation(Geometry):
             geometry.bounding_box[2] + v[1],
             geometry.bounding_box[3] + v[1],
         ]
-        self.feature_points = numpy.array([])
+        self.feature_points = np.array([])
         return
 
     def dist(self, x):
