@@ -1,29 +1,26 @@
-import numpy
+import numpy as np
 
 
 def unique_rows(a):
-    # The cleaner alternative `numpy.unique(a, axis=0)` is slow; cf.
+    # The cleaner alternative `np.unique(a, axis=0)` is slow; cf.
     # <https://github.com/numpy/numpy/issues/11136>.
-    b = numpy.ascontiguousarray(a).view(
-        numpy.dtype((numpy.void, a.dtype.itemsize * a.shape[1]))
-    )
-    a_unique, inv, cts = numpy.unique(b, return_inverse=True, return_counts=True)
+    b = np.ascontiguousarray(a).view(np.dtype((np.void, a.dtype.itemsize * a.shape[1])))
+    a_unique, inv, cts = np.unique(b, return_inverse=True, return_counts=True)
     a_unique = a_unique.view(a.dtype).reshape(-1, a.shape[1])
     return a_unique, inv, cts
 
 
 def multi_newton(x0, is_inside, boundary_step, tol, max_num_steps=10):
-    """Newton's minimization method for multiple starting points.
-    """
+    """Newton's minimization method for multiple starting points."""
     x = x0.copy()
     fx = is_inside(x.T)
 
     k = 0
-    mask = numpy.abs(fx) > tol
-    while numpy.any(mask):
+    mask = np.abs(fx) > tol
+    while np.any(mask):
         x[mask] = boundary_step(x[mask].T).T
         fx = is_inside(x.T)
-        mask = numpy.abs(fx) > tol
+        mask = np.abs(fx) > tol
         k += 1
         if k >= max_num_steps:
             break
@@ -31,16 +28,47 @@ def multi_newton(x0, is_inside, boundary_step, tol, max_num_steps=10):
     return x
 
 
-def show(pts, cells, geo, title=None):
+def show(pts, cells, geo, title=None, full_screen=True):
     import matplotlib.pyplot as plt
 
     eps = 1.0e-10
+    # hightlight outside points in C3, and points which aren't part of any cell in C4
+    is_part_of_cell = np.zeros(len(pts), dtype=bool)
+    is_part_of_cell[cells.flat] = True
+
     is_inside = geo.dist(pts.T) < eps
-    plt.plot(pts[is_inside, 0], pts[is_inside, 1], ".")
-    plt.plot(pts[~is_inside, 0], pts[~is_inside, 1], ".", color="r")
+
+    sp = pts[is_inside & is_part_of_cell]
+    plt.plot(sp[:, 0], sp[:, 1], ".", color="C0")
+    sp = pts[~is_inside]
+    plt.plot(sp[:, 0], sp[:, 1], ".", color="C3")
+    sp = pts[~is_part_of_cell]
+    plt.plot(sp[:, 0], sp[:, 1], ".", color="k")
+    # plt.plot(pts[~is_inside, 0], pts[~is_part_of_cell, 1], ".", color="k")
     plt.triplot(pts[:, 0], pts[:, 1], cells)
     plt.axis("square")
 
+    # show cells indices
+    # for idx, barycenter in enumerate(np.sum(pts[cells], axis=1) / 3):
+    #     plt.plot(*barycenter, "xk")
+    #     plt.text(
+    #         *barycenter, idx, horizontalalignment="center", verticalalignment="center"
+    #     )
+
+    # show node indices
+    # for idx, pt in enumerate(pts):
+    #     plt.text(
+    #         *pt, idx, horizontalalignment="center", verticalalignment="center"
+    #     )
+
+    if full_screen:
+        figManager = plt.get_current_fig_manager()
+        try:
+            figManager.window.showMaximized()
+        except AttributeError:
+            # Some backends have no window (e.g., Agg)
+            pass
+
     if title is not None:
         plt.title(title)
 
@@ -62,7 +90,7 @@ def find_feature_points(geometries, num_steps=10):
         for item1 in geometries[j].paths
     ]
 
-    points = numpy.column_stack(
+    points = np.column_stack(
         [
             _find_feature_points_between_two_paths(path0, path1, num_steps)
             for path0, path1 in path_pairs
@@ -75,16 +103,16 @@ def find_feature_points(geometries, num_steps=10):
     return points.T
 
 
-def _find_feature_points_between_two_paths(path0, path1, num_steps):
+def _find_feature_points_between_two_paths(path0, path1, num_steps, nx=11, ny=11):
     """Given two geometries with their parameterization, this methods finds feature
     points, i.e., points where the boundaries meet. This is done by casting a net over
     the parameter space and performing `num_steps` Newton steps. Found solutions are
     checked for uniqueness.
     """
     # Throw a net
-    t0, t1 = numpy.meshgrid(numpy.linspace(0.0, 1.0, 11), numpy.linspace(0.0, 1.0, 11))
-    t = numpy.array([t0, t1]).reshape(2, -1)
-    # t = numpy.random.rand(2, 100)
+    t0, t1 = np.meshgrid(np.linspace(0.0, 1.0, nx), np.linspace(0.0, 1.0, ny))
+    t = np.array([t0, t1]).reshape(2, -1)
+    # t = np.random.rand(2, 100)
 
     tol = 1.0e-20
 
@@ -94,28 +122,26 @@ def _find_feature_points_between_two_paths(path0, path1, num_steps):
         f_t = path0.p(t[0]) - path1.p(t[1])
 
         # remove all inf values
-        is_infinite = numpy.any(numpy.isinf(f_t), axis=0)
-        if numpy.any(is_infinite):
+        is_infinite = np.any(np.isinf(f_t), axis=0)
+        if np.any(is_infinite):
             t = t[:, ~is_infinite]
             f_t = f_t[:, ~is_infinite]
 
-        f_dot_f = numpy.einsum("ij,ij->j", f_t, f_t)
+        f_dot_f = np.einsum("ij,ij->j", f_t, f_t)
         is_sol = f_dot_f < tol
 
-        if numpy.any(is_sol):
+        if np.any(is_sol):
             solutions.append(t[:, is_sol])
             # remove all converged solutions
             t = t[:, ~is_sol]
             f_t = f_t[:, ~is_sol]
 
-        jac_t = numpy.moveaxis(
-            numpy.stack([path0.dp_dt(t[0]), -path1.dp_dt(t[1])]), 0, 1
-        )
+        jac_t = np.moveaxis(np.stack([path0.dp_dt(t[0]), -path1.dp_dt(t[1])]), 0, 1)
 
         # Kick out singular matrices
         det = jac_t[0, 0] * jac_t[1, 1] - jac_t[0, 1] * jac_t[1, 0]
-        is_singular = numpy.abs(det) < 1.0e-13
-        if numpy.any(is_singular):
+        is_singular = np.abs(det) < 1.0e-13
+        if np.any(is_singular):
             t = t[:, ~is_singular]
             f_t = f_t[:, ~is_singular]
             jac_t = jac_t[..., ~is_singular]
@@ -124,43 +150,42 @@ def _find_feature_points_between_two_paths(path0, path1, num_steps):
         sols = []
         for k in range(f_t.shape[-1]):
             try:
-                sols.append(numpy.linalg.solve(jac_t[..., k], f_t[:, k]))
-            except numpy.linalg.linalg.LinAlgError:
+                sols.append(np.linalg.solve(jac_t[..., k], f_t[:, k]))
+            except np.linalg.linalg.LinAlgError:
                 # singular matrix
-                sols.append(numpy.zeros(f_t[:, k].shape))
-        sols = numpy.array(sols).T
+                sols.append(np.zeros(f_t[:, k].shape))
+        sols = np.array(sols).T
 
         # Newton step
         t -= sols
 
         # Kick out everything that leaves the unit square
-        still_good = numpy.all((0.0 <= t) & (t <= 1.0), axis=0)
+        still_good = np.all((0.0 <= t) & (t <= 1.0), axis=0)
         t = t[:, still_good]
 
     if solutions:
-        unique_sols = unique_float_cols(numpy.column_stack(solutions))
+        unique_sols = unique_float_cols(np.column_stack(solutions))
         points0 = path0.p(unique_sols[0])
         # points1 = path1.p(unique_sols[1])
     else:
-        points0 = numpy.array([[], []])
+        points0 = np.array([[], []])
 
     return points0
 
 
 def unique_float_cols(data, k=0, tol=1.0e-10):
-    """In a (k, n) array `data`, find the unique columns.
-    """
+    """In a (k, n) array `data`, find the unique columns."""
     if k == data.shape[0]:
         return data[:, 0]
 
-    idx = numpy.argsort(data[k])
+    idx = np.argsort(data[k])
     data = data[:, idx]
 
     diff = data[k, 1:] - data[k, :-1]
     cut = diff > tol
 
-    idx = numpy.where(cut)[0]
-    chunks = numpy.split(data, idx + 1, axis=1)
+    idx = np.where(cut)[0]
+    chunks = np.split(data, idx + 1, axis=1)
 
-    out = numpy.column_stack([unique_float_cols(chunk, k + 1, tol) for chunk in chunks])
+    out = np.column_stack([unique_float_cols(chunk, k + 1, tol) for chunk in chunks])
     return out
