@@ -1,4 +1,4 @@
-import numpy
+import numpy as np
 
 from dmsh.geometry import pypathlib
 
@@ -9,8 +9,8 @@ def test_squared_distance():
     dist = path.squared_distance(
         [[0.2, 0.1], [0.5, 0.5], [1.0, 0.5], [0.0, 1.1], [-0.1, 1.1], [1.0, 1.0]]
     )
-    ref = numpy.array([0.01, 0.16, 1.0 / 104.0, 0.01, 0.02, 0.0])
-    assert numpy.all(numpy.abs(dist - ref) < 1.0e-12)
+    ref = np.array([0.01, 0.16, 1.0 / 104.0, 0.01, 0.02, 0.0])
+    assert np.all(np.abs(dist - ref) < 1.0e-12)
     return
 
 
@@ -20,8 +20,8 @@ def test_one_point():
     dist = path.squared_distance(
         [[0.2, 0.1], [0.5, 0.5], [1.0, 0.5], [0.0, 1.1], [-0.1, 1.1], [1.0, 1.0]]
     )
-    ref = numpy.array([0.05, 0.5, 1.25, 1.21, 1.22, 2.0])
-    assert numpy.all(numpy.abs(dist - ref) < 1.0e-12)
+    ref = np.array([0.05, 0.5, 1.25, 1.21, 1.22, 2.0])
+    assert np.all(np.abs(dist - ref) < 1.0e-12)
     return
 
 
