@@ -1,6 +1,7 @@
-import dmsh
 from helpers import assert_norm_equality, save
 
+import dmsh
+
 
 def test(show=False):
     geo = dmsh.Rectangle(0.0, 1.0, 0.0, 1.0)
@@ -11,9 +12,9 @@ def test(show=False):
     def edge_size(x):
         return 0.03 + 0.1 * p1.dist(x)
 
-    X, cells = dmsh.generate(geo, edge_size, show=show, tol=1.0e-10)
+    X, cells = dmsh.generate(geo, edge_size, show=show, tol=1.0e-10, max_steps=100)
 
-    ref_norms = [3.8844963377954718e02, 1.5689926870601147e01, 1.0000000000000000e00]
+    ref_norms = [3.8828407463996700e02, 1.5681640918183025e01, 1.0000000000000000e00]
     assert_norm_equality(X.flatten(), ref_norms, 1.0e-3)
     return X, cells
 
